/*
 * VerletWeis 
 * Copyright 2004 Giuseppe Foffi & Gavin McCullagh 
 * www_gmc@fiachra.ucd.ie
 */
/*
 * This file is part of VerletWeis.
 * VerletWeis is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * VerletWeis is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Foobar; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#include <iostream>
#include <unistd.h>
#include "CarnahanStarling.h"


/*
 * Usage
 */
void usage(int argc, char **argv)
{
  cout  
    << "Prints Compressibility & Free Energy for Carnahan Starling Hard Sphere Fluid" << endl
    << "Usage : getCarnahanStarling" << endl
    << "\t [-b beta] Def: 1.0" << endl
    << "\t [-p packing fraction] Def: 0.49" << endl
    << "\t [-h ] prints this help message" << endl
    ;
}

/*
 * Process the command line Options
 */
void readCommandLineOptions(int argc, char **argv, 
    double& phi, double& beta)
{
  if(argc > 1) {
    int c;
    // print options back to command line
    //for(int i = 0; i < argc; ++i) cout << i << " " << argv[i] << endl;

    // loop over options
    while( (c = getopt(argc, argv, "b:p:h:") ) != EOF) {

      switch(c) {
        case 'b':
          beta = atof(optarg);
          break;
        case 'p':
          phi = atof(optarg);
          break;
        case 'h':
          usage(argc, argv);
          break;
        default:
          usage(argc, argv);
          exit(1);
      }
    }
  }
}

/*
 * Simple main function
 */
int main(int argc, char **argv) 
{

  double phi(0.49), beta(1.0);
 
  readCommandLineOptions(argc,argv,phi,beta);

  CarnahanStarling* myCS = new CarnahanStarling(phi,beta);
  cout << "# Carnahan Starling Fluid: " << endl
       << "# Beta Phi Compressibility Z A " << endl
       << beta << " " << phi << " " << myCS->getCompressibility() << " " 
       << myCS->getZ() << " " << myCS->getAHS() << endl;

}

